@@ -23,7 +23,7 @@ THE SOFTWARE.
 
 '''
 
-VERSION = (0, 5, 0)
+VERSION = (0, 5, 1)
 
 from cymysql.constants import FIELD_TYPE
 from cymysql.converters import escape_dict, escape_sequence, escape_string
@@ -89,7 +89,10 @@ def Connect(*args, **kwargs):
     Connect to the database; see connections.Connection.__init__() for
     more information.
     """
-    from cymysql.connections import Connection
+    try:
+        from cymysql.connectionsx import Connection
+    except ImportError:
+        from cymysql.connections import Connection
     return Connection(*args, **kwargs)
 
 def get_client_info():  # for MySQLdb compatibility
@@ -121,7 +124,7 @@ __all__ = [
     'InterfaceError', 'InternalError', 'MySQLError', 'NULL', 'NUMBER',
     'NotSupportedError', 'DBAPISet', 'OperationalError', 'ProgrammingError',
     'ROWID', 'STRING', 'TIME', 'TIMESTAMP', 'Warning', 'apilevel', 'connect',
-    'connections', 'constants', 'converters', 'cursors',
+    'constants', 'converters', 'cursors',
     'escape_dict', 'escape_sequence', 'escape_string', 'get_client_info',
     'paramstyle', 'threadsafety', 'version_info',
 
