@@ -1,19 +1,11 @@
 # Python implementation of the MySQL client-server protocol
 #   http://forge.mysql.com/wiki/MySQL_Internals_ClientServer_Protocol
 
-try:
-    import hashlib
-    sha_new = lambda *args, **kwargs: hashlib.new("sha1", *args, **kwargs)
-except ImportError:
-    import sha
-    sha_new = sha.new
+import hashlib
+sha_new = lambda *args, **kwargs: hashlib.new("sha1", *args, **kwargs)
 
 import socket
-try:
-    import ssl
-    SSL_ENABLED = True
-except ImportError:
-    SSL_ENABLED = False
+import ssl
 
 import struct
 import sys
@@ -23,14 +15,14 @@ try:
 except ImportError:
     import configparser
 
-try:
-    import getpass
-    DEFAULT_USER = getpass.getuser()
-except ImportError:
-    DEFAULT_USER = None
+import getpass
+DEFAULT_USER = getpass.getuser()
 
 from cymysql.charset import charset_by_name, charset_by_id
-from cymysql.cursors import Cursor
+try:
+    from cymysql.cursorsx import Cursor
+except ImportError:
+    from cymysql.cursors import Cursor
 from cymysql.constants.CLIENT import *
 from cymysql.constants.COMMAND import *
 from cymysql.converters import escape_item, encoders, decoders
@@ -157,23 +149,6 @@ def _hash_password_323(password):
     return struct.pack(">LL", r1, r2)
 
 
-def defaulterrorhandler(connection, cursor, errorclass, errorvalue):
-    err = errorclass, errorvalue
-    if DEBUG:
-        raise
-
-    if cursor:
-        cursor.messages.append(err)
-    else:
-        connection.messages.append(err)
-    del cursor
-    del connection
-
-    if not issubclass(errorclass, Error):
-        raise Error(errorclass, errorvalue)
-    else:
-        raise errorclass(errorvalue[0], errorvalue[1])
-
 
 class Connection(object):
     """
@@ -181,7 +156,24 @@ class Connection(object):
 
     The proper way to get an instance of this class is to call
     connect()."""
-    errorhandler = defaulterrorhandler
+
+    def errorhandler(connection, cursor, errorclass, errorvalue):
+        err = errorclass, errorvalue
+        if DEBUG:
+            raise
+
+        if cursor:
+            cursor.messages.append(err)
+        else:
+            connection.messages.append(err)
+        del cursor
+        del connection
+
+        if not issubclass(errorclass, Error):
+            raise Error(errorclass, errorvalue)
+        else:
+            raise errorclass(errorvalue[0], errorvalue[1])
+
 
     def __init__(self, host="localhost", user=None, passwd="",
                  db=None, port=3306, unix_socket=None,
@@ -226,8 +218,6 @@ class Connection(object):
 
         self.ssl = False
         if ssl:
-            if not SSL_ENABLED:
-                raise NotImplementedError("ssl module not found")
             self.ssl = True
             client_flag |= SSL
             for k in ('key', 'cert', 'ca'):
