@@ -61,8 +61,7 @@ class MysqlPacket(object):
     def __recv_from_socket(self, size):
         r = b''
         while size:
-            nbytes = size if size < 8192 else 8192
-            recv_data = self.connection.socket.recv(nbytes)
+            recv_data = self.connection.socket.recv(size)
             recieved = len(recv_data)
             if recieved == 0:
                 break
@@ -180,11 +179,8 @@ class MysqlPacket(object):
         field_count = ord(self.get_bytes(0))
         return field_count >= 1 and field_count <= 250
   
-    def is_error_packet(self):
-        return ord(self.get_bytes(0)) == 255
-  
     def check_error(self):
-        if self.is_error_packet():
+        if ord(self.get_bytes(0)) == 255:
             self.rewind()
             self.advance(1)  # field_count == error (we already know that)
             errno = unpack_uint16(self.read(2))
@@ -300,10 +296,17 @@ class MySQLResult(object):
         self._get_descriptions()
         self._read_rowdata_packet()
 
+    def _field_data(self, packet, decoders, field):
+        data = packet.read_length_coded_string()
+        if data != None and field.type_code in decoders:
+            return decoders[field.type_code](self.connection, field, data)
+        return None
+
     # TODO: implement this as an iteratable so that it is more
     #       memory efficient and lower-latency to client...
     def _read_rowdata_packet(self):
       """Read a rowdata packet for each data row in the result set."""
+      decoders = self.connection.decoders
       rows = []
       while True:
         packet = self.connection.read_packet()
@@ -313,21 +316,11 @@ class MySQLResult(object):
             self.has_next = (server_status
                              & SERVER_STATUS.SERVER_MORE_RESULTS_EXISTS)
             break
-
-        row = []
-        for field in self.fields:
-            data = packet.read_length_coded_string()
-            converted = None
-            if field.type_code in self.connection.decoders:
-                converter = self.connection.decoders[field.type_code]
-                if data != None:
-                    converted = converter(self.connection, field, data)
-            row.append(converted)
-
-        rows.append(tuple(row))
+        rows.append(tuple([self._field_data(packet, decoders, self.fields[i])
+                                            for i in range(len(self.fields))]))
 
       self.affected_rows = len(rows)
-      self.rows = tuple(rows)
+      self.rows = rows
 
     def _get_descriptions(self):
         """Read a column descriptor packet for each column in the result."""
